@@ -48,7 +48,7 @@ BlockBox::BlockBox(Glib::RefPtr<Gnome::Conf::Client> conf_client):
     
     m_ref_charset = Gtk::ListStore::create(m_mod_col);
     m_cmb_charset.set_model(m_ref_charset);
-    m_cmb_charset.pack_start(m_mod_col.m_col_name); 
+    m_cmb_charset.pack_start(m_mod_col.m_col_name);
 
     m_hsl_stringlength.set_adjustment(m_adj_stringlength);
     m_hsl_stringnum.set_adjustment(m_adj_stringnum);
@@ -72,25 +72,31 @@ BlockBox::BlockBox(Glib::RefPtr<Gnome::Conf::Client> conf_client):
     append_charset(4, dlg_charset_choice5);
     append_charset(5, dlg_charset_choice6);
 
-    m_ali_charset.set_padding(70,70,70,70);
+    m_ali_charset.set_padding(30,30,30,30);
     m_ali_charset.add(m_cmb_charset);
     m_frm_charset.add(m_ali_charset);
     
     m_hbb_buttons.pack_start(m_btn_play);
     
-    pack_start(m_frm_stringlength);    
-    pack_start(m_frm_stringnum);
-    pack_start(m_frm_charset);
-    pack_start(m_hbb_buttons);
+    m_box_main.pack_start(m_frm_stringlength, Gtk::PACK_SHRINK);
+    m_box_main.pack_start(m_frm_stringnum, Gtk::PACK_SHRINK);
+    m_box_main.pack_start(m_frm_charset, Gtk::PACK_SHRINK);
+    m_box_main.pack_start(m_hbb_buttons);
+
+    pack_start(m_box_main);
+    pack_start(m_box_check);
     
     m_btn_play.signal_clicked().connect( sigc::mem_fun(*this, &BlockBox::on_btn_play_clicked) );
     m_cmb_charset.signal_changed().connect( sigc::mem_fun(*this, &BlockBox::on_cmb_charset_changed) );
+    
+    signal_exercise_started().connect( sigc::mem_fun(m_box_check, &CheckBox::on_exercise_started) );
+    signal_exercise_finished().connect( sigc::mem_fun(m_box_check, &CheckBox::on_exercise_finished) );    
 }
 
 BlockBox::~BlockBox()
 {}
 
-sigc::signal<void, unsigned int>& BlockBox::signal_exercise_started()
+sigc::signal<void, unsigned int, unsigned int, std::string>& BlockBox::signal_exercise_started()
 {
     return m_started;
 }
@@ -123,12 +129,12 @@ void BlockBox::on_btn_play_clicked()
     unsigned int pitch = (unsigned int) m_conf_client->get_float("/apps/gtkmmorse/keyer/pitch");
     unsigned int keyspeed = (unsigned int) m_conf_client->get_float("/apps/gtkmmorse/keyer/keyspeed");
     unsigned int charpause = (unsigned int) m_conf_client->get_float("/apps/gtkmmorse/keyer/charpause");
-    unsigned int strpause = (unsigned int) m_conf_client->get_float("/apps/gtkmmorse/keyer/strpause");
-
+    unsigned int strpause = (unsigned int) m_conf_client->get_float("/apps/gtkmmorse/keyer/stringpause");
+    
     unsigned int strnum = (unsigned int) m_hsl_stringnum.get_value();
     unsigned int strlen = (unsigned int) m_hsl_stringlength.get_value();
 
-    m_started.emit(strnum);
+    m_started.emit(strnum, strlen, m_charset);
 
     m_audioout = new libaudiostream::oastream();
 
@@ -142,7 +148,7 @@ void BlockBox::on_btn_play_clicked()
     
     m_audioout->enqueue_pause(begin_pause*1000);
     
-    current_keyer<<blocks_exc;
+    current_keyer << blocks_exc;
     
     m_audioout->play();
 
